@@ -1,7 +1,7 @@
-# Copyright (c) 2008-2015 MetPy Developers.
+# Copyright (c) 2016 University Corporation for Atmospheric Research/Unidata.
 # Distributed under the terms of the BSD 3-Clause License.
 # SPDX-License-Identifier: BSD-3-Clause
-"Experimental backend for using xarray to talk to TDS over CDMRemote"
+"""Experimental backend for using xarray to talk to TDS over CDMRemote"""
 
 from xarray import Variable
 from xarray.backends.common import AbstractDataStore
