@@ -1,4 +1,4 @@
-# Copyright (c) 2013-2015 Unidata.
+# Copyright (c) 2013-2015 University Corporation for Atmospheric Research/Unidata.
 # Distributed under the terms of the MIT License.
 # SPDX-License-Identifier: MIT
 """
@@ -6,8 +6,9 @@ This module contains code to support making data requests to
 the radar data query service (radar server) on a THREDDS Data Server (TDS).
 This includes forming proper queries as well as parsing the returned catalog.
 """
-import xml.etree.ElementTree as ET
+
 from collections import namedtuple
+import xml.etree.ElementTree as ET
 
 from .catalog import TDSCatalog
 from .http_util import BadQueryError, DataQuery, HTTPEndPoint, urljoin
@@ -78,7 +79,7 @@ class RadarServer(HTTPEndPoint):
     def _get_metadata(self):
         ds_cat = TDSCatalog(self.url_path('dataset.xml'))
         self.metadata = ds_cat.metadata
-        self.variables = set(k.split('/')[0] for k in self.metadata['variables'].keys())
+        self.variables = {k.split('/')[0] for k in self.metadata['variables'].keys()}
         self._get_stations()
 
     def _get_stations(self, station_file='stations.xml'):
